Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(181)

Unified Diff: tools/gn/function_get_path_info_unittest.cc

Issue 857163002: Absolute path fixes for gn. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: tools/gn/function_get_path_info_unittest.cc
diff --git a/tools/gn/function_get_path_info_unittest.cc b/tools/gn/function_get_path_info_unittest.cc
index 855e217accf508b52379003854118564185606fc..836af9787890111902cb21ca6f11d5a24279623e 100644
--- a/tools/gn/function_get_path_info_unittest.cc
+++ b/tools/gn/function_get_path_info_unittest.cc
@@ -95,8 +95,8 @@ TEST_F(GetPathInfoTest, OutDir) {
EXPECT_EQ("//out/Debug/obj/src/foo", Call(".", "out_dir"));
EXPECT_EQ("//out/Debug/obj/src/foo", Call("bar", "out_dir"));
EXPECT_EQ("//out/Debug/obj/foo", Call("//foo/bar.txt", "out_dir"));
- // System paths go into the root obj directory.
- EXPECT_EQ("//out/Debug/obj", Call("/foo/bar.txt", "out_dir"));
+ // System paths go into the ABS_PATH obj directory.
+ EXPECT_EQ("//out/Debug/obj/ABS_PATH/foo", Call("/foo/bar.txt", "out_dir"));
}
// Note build dir is "//out/Debug/".
« no previous file with comments | « tools/gn/filesystem_utils_unittest.cc ('k') | tools/gn/label.cc » ('j') | tools/gn/label.cc » ('J')

Powered by Google App Engine
This is Rietveld 408576698